Module qcs_api::apis::authentication_api
source · [−]Enums
struct for typed errors of method auth_email_password_reset_token
struct for typed errors of method auth_get_user
struct for typed errors of method auth_reset_password
struct for typed errors of method auth_reset_password_with_token
Functions
Send a password reset link to the provided email address, if that email matches a registered user.
Retrieve the profile of the authenticated user.
Reset the password using the user’s existing password. Note, this is an authenticated route.
Complete the forgot password flow, resetting the new password in exchange for an emailed token.