auth_email_password_reset_token

Function auth_email_password_reset_token 

pub async fn auth_email_password_reset_token(
    configuration: &Configuration,
    auth_email_password_reset_token_request: Option<AuthEmailPasswordResetTokenRequest>,
) -> Result<(), Error<AuthEmailPasswordResetTokenError>>
Send a password reset link to the provided email address, if that email matches a registered user.