pub struct BillingCustomer {
pub email: String,
pub id: String,
}Expand description
BillingCustomer : A representation of a QCS’s account billing customer. Note, balance does not account for the upcoming invoice.
Fields
email: Stringid: StringImplementations
Sourceimpl BillingCustomer
impl BillingCustomer
Sourcepub fn new(email: String, id: String) -> BillingCustomer
pub fn new(email: String, id: String) -> BillingCustomer
A representation of a QCS’s account billing customer. Note, balance does not account for the upcoming invoice.