Module billing_price

Module billing_price 

Structs

BillingPrice
BillingPrice : The price schedule for a particular service applied to an invoice line item.

Enums

Object
String representing the object’s type. Objects of the same type share the same value.
PriceType
One of one_time or recurring depending on whether the price is for a one-time purchase or a recurring (subscription) purchase.