Struct qcs_api::models::characteristic::Characteristic
source · [−]pub struct Characteristic {
pub error: Option<f32>,
pub name: String,
pub node_ids: Option<Vec<i32>>,
pub parameter_values: Option<Vec<f32>>,
pub timestamp: String,
pub value: f32,
}Expand description
Characteristic : A measured characteristic of an operation.
Fields
error: Option<f32>The error in the characteristic value, or None otherwise.
name: StringThe name of the characteristic.
node_ids: Option<Vec<i32>>The list of architecture node ids for the site where the characteristic is measured, if that is different from the site of the enclosing operation. None if it is the same. The order of this or the enclosing node ids obey the definition of node symmetry from the enclosing operation.
parameter_values: Option<Vec<f32>>The optional ordered list of parameter values used to generate the characteristic. The order matches the parameters in the enclosing operation, and so the lengths of these two lists must match.
timestamp: StringThe date and time at which the characteristic was measured.
value: f32The characteristic value measured.
Implementations
sourceimpl Characteristic
impl Characteristic