pub struct CreateEndpointParameters {
pub quantum_processor_id: String,
}Expand description
CreateEndpointParameters : A publicly available set of parameters for defining an endpoint.
Fields
quantum_processor_id: StringPublic identifier for a quantum processor [example: Aspen-1]
Implementations
sourceimpl CreateEndpointParameters
impl CreateEndpointParameters
sourcepub fn new(quantum_processor_id: String) -> CreateEndpointParameters
pub fn new(quantum_processor_id: String) -> CreateEndpointParameters
A publicly available set of parameters for defining an endpoint.