Struct qcs_api::models::create_engagement_request::CreateEngagementRequest [−][src]
pub struct CreateEngagementRequest {
pub account_id: Option<String>,
pub account_type: Option<Box<AccountType>>,
pub endpoint_id: Option<String>,
pub quantum_processor_id: Option<String>,
pub tags: Option<Vec<String>>,
}Fields
account_id: Option<String>Either the client’s user ID or the name of a group on behalf of which the client wishes to engage
account_type: Option<Box<AccountType>>Indicates whether the engagement request should be made for the user or on behalf of a group
endpoint_id: Option<String>Unique, opaque identifier for the endpoint
quantum_processor_id: Option<String>Public identifier for a quantum processor [example: Aspen-1]
Tags recorded on QPU requests, which reporting services may later use for querying usage records.
Implementations