pub enum Family {
None,
Full,
Aspen,
}Expand description
Family : Family identifier. Value ‘None’ implies the architecture has no specific layout topology. Value ‘Full’ implies every node is connected to every other node (a fully-connected architecture). Value ‘Aspen’ implies the architecture adheres the to the Aspen topology conventions for node numbering and edge connectivity. Family identifier. Value ‘None’ implies the architecture has no specific layout topology. Value ‘Full’ implies every node is connected to every other node (a fully-connected architecture). Value ‘Aspen’ implies the architecture adheres the to the Aspen topology conventions for node numbering and edge connectivity.
Variants