pub struct InstructionSetArchitecture {
pub architecture: Box<Architecture1>,
pub benchmarks: Vec<Operation>,
pub instructions: Vec<Operation>,
pub name: String,
}Expand description
InstructionSetArchitecture : The native instruction set architecture of a quantum processor, annotated with characteristics. The operations described by the instructions field are named by their QUIL instruction name, while the operation described by the benchmarks field are named by their benchmark routine and are a future extension point that will be populated in future iterations. The characteristics that annotate both instructions and benchmarks assist the user to generate the best native QUIL program for a desired task, and so are provided as part of the native ISA.
Fields
architecture: Box<Architecture1>benchmarks: Vec<Operation>The list of benchmarks that have characterized the quantum processor.
instructions: Vec<Operation>The list of native QUIL instructions supported by the quantum processor.
name: StringThe name of the quantum processor.
Implementations
Sourceimpl InstructionSetArchitecture
impl InstructionSetArchitecture
Sourcepub fn new(
architecture: Architecture1,
benchmarks: Vec<Operation>,
instructions: Vec<Operation>,
name: String,
) -> InstructionSetArchitecture
pub fn new( architecture: Architecture1, benchmarks: Vec<Operation>, instructions: Vec<Operation>, name: String, ) -> InstructionSetArchitecture
The native instruction set architecture of a quantum processor, annotated with characteristics. The operations described by the instructions field are named by their QUIL instruction name, while the operation described by the benchmarks field are named by their benchmark routine and are a future extension point that will be populated in future iterations. The characteristics that annotate both instructions and benchmarks assist the user to generate the best native QUIL program for a desired task, and so are provided as part of the native ISA.