Struct qcs_api::models::internal_create_reservation_request::InternalCreateReservationRequest
source · [−]pub struct InternalCreateReservationRequest {
pub account_id: Option<String>,
pub account_type: Option<AccountType>,
pub end_time: String,
pub notes: Option<String>,
pub quantum_processor_id: String,
pub start_time: String,
pub epoch_seconds: Option<i32>,
pub is_reschedule: Option<bool>,
pub user_id: Option<String>,
pub validate_availability: Option<bool>,
pub validate_other: Option<bool>,
}Fields
account_id: Option<String>userId for accountType "user", group name for accountType "group".
account_type: Option<AccountType>end_time: Stringnotes: Option<String>quantum_processor_id: Stringstart_time: Stringepoch_seconds: Option<i32>is_reschedule: Option<bool>If true, the user will receive an email notify them their reservation was re-scheduled. Otherwise, they will receive the regular confirmation email.
user_id: Option<String>validate_availability: Option<bool>When false, this will create double booked reservations where time is already reserved.
validate_other: Option<bool>When false, this will not validate maximum reservation duration or past and maximum future start times.
Implementations