pub struct TranslateNativeQuilToEncryptedBinaryResponse {
pub memory_descriptors: Option<HashMap<String, ParameterSpec>>,
pub program: String,
pub ro_sources: Option<Vec<Vec<String>>>,
pub settings_timestamp: Option<String>,
}Fields
memory_descriptors: Option<HashMap<String, ParameterSpec>>program: StringEncrypted binary built for execution on the target quantum processor
ro_sources: Option<Vec<Vec<String>>>settings_timestamp: Option<String>ISO8601 timestamp of the settings used to translate the program. Translation is deterministic; a program translated twice with the same settings by the same version of the service will have identical output.
Implementations