Struct qcs_api::models::create_endpoint_parameters::CreateEndpointParameters [−][src]
pub struct CreateEndpointParameters {
pub quantum_processor_id: String,
}Expand description
CreateEndpointParameters : A publicly available set of parameters for defining an endpoint.
Fields
quantum_processor_id: StringPublic identifier for a quantum processor [example: Aspen-1]
Implementations
A publicly available set of parameters for defining an endpoint.