pub struct Endpoint {
pub address: String,
pub addresses: Box<EndpointAddresses>,
pub datacenter: Option<String>,
pub healthy: bool,
pub id: String,
pub mock: bool,
pub quantum_processor_ids: Option<Vec<String>>,
}Expand description
Endpoint : An Endpoint is the entry point for remote access to a QuantumProcessor.
Fields
address: StringNetwork address at which the endpoint is locally reachable
addresses: Box<EndpointAddresses>datacenter: Option<String>Datacenter within which the endpoint is deployed
healthy: boolWhether the endpoint is operating as intended
id: StringUnique, opaque identifier for the endpoint
mock: boolWhether the endpoint serves simulated or substituted data for testing purposes
quantum_processor_ids: Option<Vec<String>>Public identifiers for quantum processors served by this endpoint.
Implementations