pub struct Endpoint {
    pub address: String,
    pub healthy: bool,
    pub id: String,
    pub mock: bool,
    pub quantum_processor_id: String,
}
Endpoint : An Endpoint is the entry point for remote access to a QuantumProcessor.

Fields

address: String

Network address at which the endpoint is locally reachable

healthy: bool

Whether the endpoint is operating as intended

id: String

Unique, opaque identifier for the endpoint

mock: bool

Whether the endpoint serves simulated or substituted data for testing purposes

quantum_processor_id: String

Public identifier for a quantum processor [example: Aspen-1]

Implementations

An Endpoint is the entry point for remote access to a QuantumProcessor.