Struct qcs_api::models::endpoint::Endpoint [−][src]
pub struct Endpoint {
pub address: String,
pub healthy: bool,
pub id: String,
pub mock: bool,
pub quantum_processor_id: String,
}Expand description
Endpoint : An Endpoint is the entry point for remote access to a QuantumProcessor.
Fields
address: StringNetwork address at which the endpoint is locally reachable
healthy: boolWhether the endpoint is operating as intended
id: StringUnique, opaque identifier for the endpoint
mock: boolWhether the endpoint serves simulated or substituted data for testing purposes
quantum_processor_id: StringPublic identifier for a quantum processor [example: Aspen-1]
Implementations