pub struct Operation {
pub characteristics: Vec<Characteristic>,
pub name: String,
pub node_count: Option<i32>,
pub parameters: Vec<Parameter>,
pub sites: Vec<OperationSite>,
}Expand description
Operation : An operation, with its sites and site-independent characteristics.
Fields
characteristics: Vec<Characteristic>The list of site-independent characteristics of this operation.
name: StringThe name of the operation.
node_count: Option<i32>The number of nodes that this operation applies to. None if unspecified.
parameters: Vec<Parameter>The list of parameters. Each parameter must be uniquely named. May be empty.
sites: Vec<OperationSite>The list of sites at which this operation can be applied, together with its site-dependent characteristics.
Implementations
sourceimpl Operation
impl Operation
sourcepub fn new(
characteristics: Vec<Characteristic>,
name: String,
parameters: Vec<Parameter>,
sites: Vec<OperationSite>
) -> Operation
pub fn new(
characteristics: Vec<Characteristic>,
name: String,
parameters: Vec<Parameter>,
sites: Vec<OperationSite>
) -> Operation
An operation, with its sites and site-independent characteristics.