Struct qcs_api::models::translate_native_quil_to_encrypted_binary_request::TranslateNativeQuilToEncryptedBinaryRequest
source · [−]pub struct TranslateNativeQuilToEncryptedBinaryRequest {
pub num_shots: i32,
pub quil: String,
pub settings_timestamp: Option<String>,
}Fields
num_shots: i32Number of iterations to execute on the control hardware
quil: StringThe native Quil program to be translated for execution
settings_timestamp: Option<String>ISO8601 timestamp of the latest settings to be used in translation. If omitted, latest settings will be used.
Implementations
sourceimpl TranslateNativeQuilToEncryptedBinaryRequest
impl TranslateNativeQuilToEncryptedBinaryRequest
pub fn new(
num_shots: i32,
quil: String
) -> TranslateNativeQuilToEncryptedBinaryRequest